/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import org.openide.util.Exceptions;

/**
 *
 * @author Gerben Feenstra
 */
public class SensorUtil {
    
    
    /**
     * Check if a file has a valid header conforming to the specified filedescription.
     * Calling hasValidHeader(File sensorfile, Enum[] fileDescription, int lineNumber) with 1 as linenumber
     * 
     * @param sensorfile Sensorfile to check header from
     * @param fileDescription FileDescription Enum containing all header columns for the specified sensorFile type
     * @return true when the header matches the specified fileDescription
     */
    public static boolean hasValidHeader(File sensorfile, Enum[] fileDescription){
        return hasValidHeader(sensorfile, fileDescription ,1);
    }
        
    /**
     * Check if a file has a valid header conforming to the specified filedescription.
     * MAX HEADER LENGTH = 1024 CHARACTERS, adjust this method when needed.
     * 
     * @param sensorfile Sensorfile to check header from
     * @param fileDescription FileDescription Enum containing all header columns for the specified sensorFile type
     * @param lineNumber Linenumber of file-content containing the header.
     * @return true when the header matches the specified fileDescription
     */
    public static boolean hasValidHeader(File sensorfile, Enum[] fileDescription, int lineNumber){
        String firstLine = "";
        try {
            BufferedReader br = new BufferedReader(new FileReader(sensorfile));
            
            // Skip lines when necesarry
            while(lineNumber > 1){
                br.readLine();
                lineNumber--;
            }   
            
            // Max header length
            char[] buff = new char[1024];
            br.read(buff);
            firstLine = new String(buff).toLowerCase();
            
            // firstLine should not be null. Remove spaces and underscores
            firstLine = firstLine == null ? "" : firstLine.replace(" ", "").replace("_", "");            
            br.close();
        } catch (FileNotFoundException ex) {
            Exceptions.printStackTrace(ex);
        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }  
        
        // Check if header contains all required columns
        boolean isValidHeader = true;
        for(Enum headerColumn : fileDescription){
            // Remove spaces and underscores
            String headerColumnName = headerColumn.toString().toLowerCase().replace(" ", "").replace("_", "");
            
            if(!firstLine.contains(headerColumnName)){
                isValidHeader = false;
                break;
            }    
        }
        return isValidHeader;
    }
            
}
